16 #ifndef TPFA_LINEARIZER_GPUKERNELS_HH 17 #define TPFA_LINEARIZER_GPUKERNELS_HH 27 #if HAVE_CUDA && OPM_IS_COMPILING_WITH_GPU_COMPILER 28 template <
class TpfaLinearizerType,
34 class NeighborSparseTable,
37 __global__ __launch_bounds__(256) void kernel_linearize(const
unsigned int numCells,
38 const DomainType domain,
39 const NeighborSparseTable neighborInfo,
40 DiagPtrType diagMatAddress,
41 ResidualType residual,
46 const unsigned int ii = blockIdx.x * blockDim.x + threadIdx.x;
51 std::nullptr_t dummyVelocityInfo =
nullptr;
52 TpfaLinearizerType::template linearize_cell<true, LocalResidualT>(ii,
64 template <
class TpfaLinearizerType,
65 class IntensiveQuantities,
73 linearize_bc_threadsafe(DiagPtrType diagMatAddress,
75 const BoundaryInfo boundaryInfo,
79 const unsigned int ii = blockIdx.x * blockDim.x + threadIdx.x;
80 if (ii < boundaryInfo.size()) {
81 TpfaLinearizerType::template linearize_bc_threadsafe_single_cell<IntensiveQuantities,
83 diagMatAddress, residual, boundaryInfo[ii], model, gpuProblem);
91 #endif // TPFA_LINEARIZER_GPUKERNELS_HH Structs needed for tpfalinearizer and its gpuparams struct extracted to be defined in one place that ...
Definition: blackoilbioeffectsmodules.hh:45